==> nextcloud-26.0.7.tar.bz2: nextcloud/apps/photos/l10n/id.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Tautan publik",
    "Photos" : "Foto",
    "Your memories under your control" : "Kenangan Anda di bawah kendali Anda",
    "All media" : "Semua media",
    "Videos" : "Video",
    "Albums" : "Album",
    "Collaborative albums" : "Album kolaboratif",
    "People" : "Orang",
    "Folders" : "Folder",
    "Favorites" : "Disukai",
    "On this day" : "Pada hari ini",
    "Shared with you" : "Shared with you",
    "Tags" : "Tag",
    "Places" : "Tempat",
    "Map" : "Peta",
    "Photos settings" : "Setelan foto",
    "Mark selection as favorite" : "Tandai pilihan sebagai favorit",
    "Add selection to favorites" : "Tambahkan pilihan ke favorit",
    "Remove selection from favorites" : "Hapus pilihan dari favorit",
    "Name of the album" : "Nama album",
    "Location of the album" : "Lokasi album",
    "Go back to the previous view." : "Kembali ke tampilan sebelumnya.",
    "Back" : "Kembali",
    "Go to the add collaborators view." : "Pergi ke tampilan kolaborator.",
    "Add collaborators" : "Tambahkan kolaborator",
    "Save." : "Simpan.",
    "Create the album." : "Buat album.",
    "Save" : "Simpan",
    "Create album" : "Buat album",
    "Back to the new album form." : "Kembali ke formulir album baru.",
    "Add to Album" : "Tambahkan ke Album",
    "Add selection to album {albumName}" : "Tambahkan pilihan ke album {albumName}",
    "Shared by" : "Dibagikan oleh",
    "Create a new album." : "Buat sebuah album baru.",
    "Create new album" : "Buat album baru",
    "New album" : "Album baru",
    "_%n item_::_%n photos and videos_" : ["%n foto dan video"],
    "Add people or groups who can edit your album" : "Tambahkan orang atau grup yang dapat menyunting album Anda",
    "Search people or groups" : "Cari orang atau grup",
    "Group" : "Grup",
    "Remove {collaboratorLabel} from the collaborators list" : "Hapus {collaboratorLabel} dari daftar kolaborator",
    "Copy the public link" : "Salin tautan publik",
    "Public link copied!" : "Tautan publik disalin!",
    "Copy public link" : "Salin tautan publik",
    "Delete the public link" : "Hapus tautan publik",
    "Share via public link" : "Bagikan melalui tautan publik",
    "Failed to fetch collaborators list." : "Gagal mendapatkan daftar kolaborator.",
    "Failed to update album." : "Gagal memperbarui album.",
    "This collection does not exist" : "Koleksi ini tidak ada",
    "An error occurred" : "Terjadi kesalahan",
    "Select image {imageName}" : "Pilih gambar {imageName}",
    "The file is in the favorites" : "Berkas ini dalam favorit",
    "Open the full size \"{name}\" image" : "Buka gambar \"{name}\" ukuran penuh",
    "There are no photos or videos yet!" : "Belum ada foto atau video!",
    "Add to {destination}" : "Tambahkan ke {destination}",
    "Open the \"{name}\" sub-directory" : "Buka subdirektori \"{name}\"",
    "Back to {folder}" : "Kembali ke {folder}",
    "Share this folder" : "Bagikan folder ini",
    "_{years} year ago_::_{years} years ago_" : ["{years} tahun yang lalu"],
    "Enable squared photos view" : "Aktifkan tampilan foto kotak",
    "Default Photos upload and Albums location" : "Lokasi unggahan Foto dan Album",
    "Select the default location for your media" : "Pilih lokasi bawaan untuk media Anda",
    "Invalid location selected" : "Lokasi yang tidak valid dipilih",
    "View" : "Tampilan",
    "Photos directory" : "Direktori Foto",
    "_%n photo_::_%n photos_" : ["%n foto"],
    "Manage collaborators for this album" : "Kelola kolaborator untuk album ini",
    "Open actions menu" : "Buka menu tindakan",
    "Edit album details" : "Sunting detail album",
    "Download all files in album" : "Unduh semua berkas dalam album",
    "Delete album" : "Hapus album",
    "Download selected files" : "Unduh berkas yang dipilih",
    "Remove selection from album" : "Hapus pilihan dari album",
    "This album does not have any photos or videos yet!" : "Album ini belum memiliki foto atau video apa pun!",
    "Add photos to this album" : "Tambahkan foto ke album ini",
    "Manage collaborators" : "Kelola kolaborator",
    "Save collaborators for this album." : "Simpan kolaborator untuk album ini",
    "Cover photo for album {albumName}" : "Foto cover untuk album {albumName}",
    "There is no album yet!" : "Belum ada album!",
    "This person could not be found" : "Orang ini tidak dapat ditemukan",
    "Rename person" : "Ubah nama orang",
    "Merge with different person" : "Gabungkan dengan orang yang berbeda",
    "Download selected photos" : "Unduh foto yang dipilih",
    "Favorite" : "Favorit",
    "Remove from favorites" : "Remove from favorites",
    "Remove person" : "Hapus orang",
    "Name of this person" : "Nama orang ini",
    "Merge person" : "Gabungkan orang",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Pindahkan foto ke orang yang berbeda"],
    "_Remove photo from person_::_Remove photos from person_" : ["Hapus foto dari orang"],
    "This might take some time depending on the size of your photo library." : "Ini mungkin membutuhkan beberapa waktu tergantung pada ukuran pustaka foto Anda.",
    "Recognized people will show up here" : "Orang yang dikenal akan muncul di sini",
    "This folder does not exist" : "Folder ini tidak ada",
    "Loading folders …" : "Memuat folder…",
    "No photos in here" : "Tidak ada foto di sini",
    "This place does not have any photos or videos yet!" : "Tempat ini belum memiliki foto atau video apa pun!",
    "Add photos to this place" : "Tambahkan foto ke tempat ini",
    "Cover photo for place {placeName}" : "Foto cover untuk tempat {placeName}",
    "There is no place yet!" : "Belum ada tempat!",
    "Cover photo for shared album {albumName}." : "Foto cover untuk album terbagi {albumName}.",
    "Back to tags overview" : "Kembali ke ikhtisar tag",
    "No photos with this tag yet" : "Belum ada foto dengan tag ini",
    "No tags yet" : "Belum ada tag",
    "Photos with tags will show up here" : "Foto dengan tag akan muncul di sini",
    "Popular tags" : "Tag populer",
    "Add" : "Masukkan",
    "Add to album" : "Tambahkan album",
    "Delete selection" : "Hapus pilihan",
    "No photos or videos in here" : "Tidak ada foto atau video di sini",
    "_%n photos_::_%n photos_" : ["%n foto"],
    "Failed to fetch collection." : "Gagal mengambil koleksi.",
    "Failed to fetch collections list." : "Gagal mendapatkan daftar koleksi.",
    "Failed to fetch faces list." : "Gagal mendapatkan daftar wajah.",
    "All your media" : "Semua media Anda",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Album Terbagi",
    "Shared album {title}" : "Album terbagi {title}",
    "Public album {title}" : "Album publik {title}",
    "Tagged photos" : "Foto yang memiliki tag",
    "Tagged photo {title}" : "Foto memiliki tag {title} ",
    "{title}'s face" : "Wajah {title}",
    "Failed to rename {oldName} to {faceName}." : "Gagal mengubah nama {oldName} to {faceName}.",
    "Failed to delete {faceName}." : "Gagal menghapus {faceName}.",
    "Failed to delete {fileId}." : "Gagal menghapus {field}.",
    "Failed to delete {fileName}." : "Gagal menghapus {fileName}.",
    "Failed to set favorite state for {fileId}." : "Gagal menetapkan keadaan favorit untuk {field}.",
    "Failed to set favorite state for {fileName}." : "Gagal menetapkan keadaan favorit untuk {fileName}.",
    "Locations" : "Lokasi",
    "_Share with %n user_::_Share with %n users_" : ["Bagikan dengan %n pengguna"],
    "Search for collaborators" : "Cari kolaborator",
    "Add {collaboratorLabel} to the collaborators list" : "Tambahkan {collaboratorLabel} ke daftar kolaborator",
    "No collaborators available" : "Tidak ada kolaborator yang tersedia",
    "Failed to fetch album." : "Gagal mendapatkan album.",
    "Add photos to the album" : "Tambahkan foto ke album",
    "Failed to fetch albums list." : "Gagal mendapatkan daftar album.",
    "Shared albums" : "Album terbagi",
    "Create a new album" : "Buat album baru",
    "Add selection to an album" : "Tambahkan pilihan ke sebuah album",
    "Failed to create {albumName}." : "Gagal membuat {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Gagal mengubah nama {currentAlbumName} to {newAlbumName}."
},
"nplurals=1; plural=0;");

==> nextcloud-32.0.2.tar.bz2: nextcloud/apps/photos/l10n/id.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Tautan publik",
    "Photos" : "Foto",
    "Your memories under your control" : "Kenangan Anda di bawah kendali Anda",
    "All media" : "Semua media",
    "Videos" : "Video",
    "Albums" : "Album",
    "Collaborative albums" : "Album kolaboratif",
    "People" : "Orang",
    "Folders" : "Folder",
    "Favorites" : "Disukai",
    "On this day" : "Pada hari ini",
    "Shared with you" : "Shared with you",
    "Tags" : "Tag",
    "Places" : "Tempat",
    "Map" : "Peta",
    "Photos settings" : "Setelan foto",
    "Mark selection as favorite" : "Tandai pilihan sebagai favorit",
    "Add selection to favorites" : "Tambahkan pilihan ke favorit",
    "Remove selection from favorites" : "Hapus pilihan dari favorit",
    "Name of the album" : "Nama album",
    "Location of the album" : "Lokasi album",
    "Back" : "Kembali",
    "Add collaborators" : "Tambahkan kolaborator",
    "Save" : "Simpan",
    "Create album" : "Buat album",
    "Add to Album" : "Tambahkan ke Album",
    "Add selection to album {albumName}" : "Tambahkan pilihan ke album {albumName}",
    "Shared by" : "Dibagikan oleh",
    "Create a new album." : "Buat sebuah album baru.",
    "Create new album" : "Buat album baru",
    "New album" : "Album baru",
    "_%n item_::_%n photos and videos_" : ["%n foto dan video"],
    "Failed to fetch collaborators list." : "Gagal mendapatkan daftar kolaborator.",
    "Failed to update album." : "Gagal memperbarui album.",
    "Add people or groups who can edit your album" : "Tambahkan orang atau grup yang dapat menyunting album Anda",
    "Search people or groups" : "Cari orang atau grup",
    "No recommendations. Start typing." : "Tidak ada saran. Mulai mengetik.",
    "Copy the public link" : "Salin tautan publik",
    "Public link copied!" : "Tautan publik disalin!",
    "Copy public link" : "Salin tautan publik",
    "Delete the public link" : "Hapus tautan publik",
    "Create public link share" : "Buat berbagi tautan publik",
    "Share via public link" : "Bagikan melalui tautan publik",
    "This collection does not exist" : "Koleksi ini tidak ada",
    "An error occurred" : "Terjadi kesalahan",
    "_%n photos_::_%n photos_" : ["%n foto"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n foto yang belum ditetapkan"],
    "Favorite" : "Favorit",
    "Open the full size \"{name}\" image" : "Buka gambar \"{name}\" ukuran penuh",
    "Select image {imageName}" : "Pilih gambar {imageName}",
    "Go back" : "Kembali",
    "Add to {destination}" : "Tambahkan ke {destination}",
    "There are no photos or videos yet!" : "Belum ada foto atau video!",
    "_{years} year ago_::_{years} years ago_" : ["{years} tahun yang lalu"],
    "Enable squared photos view" : "Aktifkan tampilan foto kotak",
    "Home" : "Beranda",
    "Choose default Photos upload and Albums location" : "PIlih lokasi unggahan Foto dan lokasi Album bawaan",
    "View" : "Tampilan",
    "_%n photo_::_%n photos_" : ["%n foto"],
    "Unselect all" : "Batalkan semua pemilihan",
    "Add photos to this album" : "Tambahkan foto ke album ini",
    "Manage collaborators for this album" : "Kelola kolaborator untuk album ini",
    "Open actions menu" : "Buka menu tindakan",
    "Edit album details" : "Sunting detail album",
    "Download all files in album" : "Unduh semua berkas dalam album",
    "Delete album" : "Hapus album",
    "Download selected files" : "Unduh berkas yang dipilih",
    "Remove selection from album" : "Hapus pilihan dari album",
    "This album does not have any photos or videos yet!" : "Album ini belum memiliki foto atau video apa pun!",
    "Add photos to {albumName}" : "Tambahkan foto ke {albumName}",
    "Manage collaborators" : "Kelola kolaborator",
    "Save collaborators for this album." : "Simpan kolaborator untuk album ini",
    "Cover photo for album {albumName}" : "Foto cover untuk album {albumName}",
    "There is no album yet!" : "Belum ada album!",
    "This person could not be found" : "Orang ini tidak dapat ditemukan",
    "Rename person" : "Ubah nama orang",
    "Merge with different person" : "Gabungkan dengan orang yang berbeda",
    "Download selected photos" : "Unduh foto yang dipilih",
    "Remove from favorites" : "Remove from favorites",
    "Remove person" : "Hapus orang",
    "Name of this person" : "Nama orang ini",
    "Save." : "Simpan.",
    "Merge person" : "Gabungkan orang",
    "Move to different person" : "Pindahkan ke orang lain",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Pindahkan foto ke orang yang berbeda"],
    "_Remove photo from person_::_Remove photos from person_" : ["Hapus foto dari orang"],
    "This might take some time depending on the size of your photo library." : "Ini mungkin membutuhkan beberapa waktu tergantung pada ukuran pustaka foto Anda.",
    "Recognized people will show up here" : "Orang yang dikenal akan muncul di sini",
    "This folder does not exist" : "Folder ini tidak ada",
    "Loading folders…" : "Memuat folder…",
    "No photos in here" : "Tidak ada foto di sini",
    "Taken on {date} at {time}" : "Diambil pada tanggal {date}, jam {time}",
    "This place does not have any photos or videos yet!" : "Tempat ini belum memiliki foto atau video apa pun!",
    "Add photos to this place" : "Tambahkan foto ke tempat ini",
    "Cover photo for place {placeName}" : "Foto cover untuk tempat {placeName}",
    "There is no place yet!" : "Belum ada tempat!",
    "Back to tags overview" : "Kembali ke ikhtisar tag",
    "No photos with this tag yet" : "Belum ada foto dengan tag ini",
    "No tags yet" : "Belum ada tag",
    "Photos with tags will show up here" : "Foto dengan tag akan muncul di sini",
    "Popular tags" : "Tag populer",
    "Add to album" : "Tambahkan album",
    "Delete selection" : "Hapus pilihan",
    "No photos or videos in here" : "Tidak ada foto atau video di sini",
    "Unassigned faces" : "Wajah yang belum ditetapkan",
    "Failed to fetch collection." : "Gagal mengambil koleksi.",
    "Failed to fetch collections list." : "Gagal mendapatkan daftar koleksi.",
    "Failed to fetch faces list." : "Gagal mendapatkan daftar wajah.",
    "All your media" : "Semua media Anda",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Album Terbagi",
    "Shared album {title}" : "Album terbagi {title}",
    "Public album {title}" : "Album publik {title}",
    "Tagged photos" : "Foto yang memiliki tag",
    "Tagged photo {title}" : "Foto memiliki tag {title} ",
    "{title}'s face" : "Wajah {title}",
    "Last week" : "Minggu lalu",
    "{startDate} to {endDate}" : "{startDate} ke {endDate}",
    "Details" : "Detail",
    "Group" : "Grup",
    "Remove {collaboratorLabel} from the collaborators list" : "Hapus {collaboratorLabel} dari daftar kolaborator",
    "Back to {folder}" : "Kembali ke {folder}",
    "Share this folder" : "Bagikan folder ini",
    "Loading folders …" : "Memuat folder…",
    "Add" : "Masukkan"
},
"nplurals=1; plural=0;");
